package com.ynet.life.loaf.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.action.LifeJDBCAction;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.LoafTools;
import com.ynet.life.loaf.jdbc.LoafQueryFactory;
import com.ynet.life.loaf.jdbc.LoafQueryInterface;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_loaf_action.jar:com/ynet/life/loaf/action/QueryDataListByPageUsingSQLAction.class */
public class QueryDataListByPageUsingSQLAction extends LifeJDBCAction {
    private static final String FIELD_SEPERATOR = "||";
    private String queryFields;
    protected String querySql;
    protected List inputFields;
    private List outputFields;
    private String sortParam;
    private String iCollName;
    private String beginPosFieldName;
    private String showNumFieldName;
    private String totalNumFieldName;
    private static final String ERROR_CODE_POOL = "EBLN0011";
    private String inCondName;
    private String inCondParams;

    public void setInCondName(String inCondName) {
        this.inCondName = "%".concat(String.valueOf(inCondName));
    }

    public void setInCondParams(String inCondParams) {
        this.inCondParams = inCondParams;
    }

    public String execute(Context context) throws GENEException {
        LoafQueryInterface query;
        if (this.iCollName == null || "".equals(this.iCollName)) {
            throw new TranFailException(ERROR_CODE_POOL, "存储输出结果的数据域集合名称不能为空");
        }
        if (this.querySql == null || "".equals(this.querySql)) {
            throw new TranFailException(ERROR_CODE_POOL, "查询sql语句不能为空");
        }
        if (this.outputFields == null || "".equals(this.outputFields)) {
            throw new TranFailException(ERROR_CODE_POOL, "存储输出结果的数据域名称不能为空");
        }
        if (this.queryFields == null || "".equals(this.queryFields)) {
            throw new TranFailException(ERROR_CODE_POOL, "出现在查询结果中的列不能为空");
        }
        String sqlTmp = this.querySql;
        if (this.inCondParams != null && !"".equals(this.inCondParams)) {
            String condiVal = (String) context.getDataValue(this.inCondParams);
            sqlTmp = !"".equals(condiVal) ? sqlTmp.replaceAll(this.inCondName, "in (" + condiVal + ")") : sqlTmp.replaceAll(this.inCondName, "= null");
        }
        try {
            try {
                IndexedCollection outputIColl = (IndexedCollection) context.get(this.iCollName);
                List input = new LinkedList();
                String finalSQL = LoafTools.parseQuerySql(context, sqlTmp, input);
                if (this.sortParam != null && this.sortParam.equals("sortParam")) {
                    query = LoafQueryFactory.getNewQuery(this.queryFields, (String) context.get(this.sortParam), finalSQL);
                } else {
                    query = LoafQueryFactory.getNewQuery(this.queryFields, this.sortParam, finalSQL);
                }
                Connection connection = LifeDBAccess.getConnection(getDataSource());
                int totalNum = query.getCount(connection, input);
                Trace.logDebug("LOAF", "查询条件--->".concat(String.valueOf(query)));
                Trace.logDebug("LOAF", "输入参数--->".concat(String.valueOf(input)));
                if (totalNum > 0) {
                    PreparedStatement ps = null;
                    ResultSet resultSet = null;
                    try {
                        try {
                            int beginPos = Integer.parseInt((String) context.get(this.beginPosFieldName));
                            int showNum = Integer.parseInt((String) context.get(this.showNumFieldName));
                            PreparedStatement queryByPageStatement = query.getQueryByPageStatement(connection, input, beginPos, showNum);
                            ps = queryByPageStatement;
                            resultSet = queryByPageStatement.executeQuery();
                            fillResultIntoIcoll(resultSet, outputIColl);
                            LifeDBAccess.cleanResources(ps, resultSet);
                        } catch (SQLException ex) {
                            throw new TranFailException("EBLN0000", ex);
                        }
                    } catch (Throwable th) {
                        LifeDBAccess.cleanResources(ps, resultSet);
                        throw th;
                    }
                }
                context.put(this.totalNumFieldName, String.valueOf(totalNum));
                Trace.logDebug("LOAF", "查询结果--->\n".concat(String.valueOf(outputIColl)));
                LifeDBAccess.releaseConnection(getDataSource(), connection);
                return String.valueOf(totalNum);
            } catch (GENEException empe) {
                Trace.logError("LOAF", empe.getMessage(), empe);
                throw empe;
            }
        } catch (Throwable th2) {
            LifeDBAccess.releaseConnection(getDataSource(), (Connection) null);
            throw th2;
        }
    }

    private void fillResultIntoIcoll(ResultSet resultSet, IndexedCollection input) throws SQLException {
        KeyedCollection singleRecord;
        int dateSize = this.outputFields.size();
        while (resultSet.next()) {
            KeyedCollection singleRecord2 = input.getDataElement();
            if (singleRecord2 != null) {
                singleRecord = (KeyedCollection) singleRecord2.clone();
            } else {
                singleRecord = new KeyedCollection();
            }
            for (int i = 1; i <= dateSize; i++) {
                String dataFieldValue = resultSet.getString(i);
                singleRecord.put(this.outputFields.get(i - 1), dataFieldValue);
            }
            input.addDataElement(singleRecord);
        }
    }

    public void setICollName(String collName) {
        this.iCollName = collName;
    }

    public void setBeginPosFieldName(String beginPosFieldName) {
        this.beginPosFieldName = beginPosFieldName;
    }

    public void setShowNumFieldName(String showNumFieldName) {
        this.showNumFieldName = showNumFieldName;
    }

    public void setTotalNumFieldName(String totalNumFieldName) {
        this.totalNumFieldName = totalNumFieldName;
    }

    public void setQueryFields(String queryFields) {
        this.queryFields = queryFields;
    }

    public void setQuerySql(String querySql) {
        System.out.print("11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111");
        this.querySql = querySql;
    }

    public void setSortParam(String sortParam) {
        this.sortParam = sortParam;
    }

    public void setInputFields(String inputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(inputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.inputFields = result;
    }

    public void setOutputFields(String outputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFields = result;
    }
}
